@@ -8,5 +8,5 @@ setup(
     description='CFFI Fibonacci',
     py_modules=['fibcffi'],
     cffi_modules=['fibcffi_build.py:ffibuilder'],
-    zip_safe=True,
+    zip_safe=False,
 )
